﻿//     Copyright (c) Microsoft Corporation.  All rights reserved.

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web;
using System.Web.Http;
using System.Web.Http.Description;
using Gateway.Console.Models;

namespace Gateway.Console.Controllers
{
    public class AnalyticsApiController : ApiController
    {
        private ConsoleContext db = new ConsoleContext();

        // GET api/AnalyticsApi/report
        public IHttpActionResult Get(string id)
        {
            var reportModel = db.AnalyticsReportModels
                .Where(model => model.Report == id)
                .FirstOrDefault();
            if (reportModel == null)
            {
                return NotFound();
            }
            if (!reportModel.HasMultipleSeries)
            {
                return Ok(new[] { reportModel.Rows
                    .OrderBy(row => row.Date)
                    .Select(row => new List<Object> { row.Date, row.Value })});
            }
            else
            {
                var seriesResults = reportModel.Rows
                    .GroupBy(row => row.Series)
                    .OrderBy(series => series.Key)
                    .ToList();
                return Ok(new
                {
                    labels = seriesResults.Select(series => series.Key),
                    data = seriesResults
                        .Select(series => series
                            .Select(row => new List<Object> { row.Date, row.Value })),
                });
            }

        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}