﻿//     Copyright (c) Microsoft Corporation.  All rights reserved.

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web;
using System.Web.Http;
using System.Web.Http.Description;
using Microsoft.Gateway.Configuration;

namespace Gateway.Console.Models
{
    public class RoleApiController : ApiController
    {
        private ConsoleContext db = new ConsoleContext();

        // GET api/RoleApi
        public GatewayConfigurationIndex Get()
        {
            var index = new GatewayConfigurationIndex();
            var s = db.SecurityModels.FirstOrDefault();
            if (s != null)
            {
                index.ApplicationName = s.ApplicationName;
                index.Directory = s.Directory;
            }
            var url = HttpContext.Current.Request.Url;
            foreach (var r in db.RoleModels)
            {
                var role = r.Role;
                var roleConfig = new UriBuilder(url) { Path = "api/RoleApi/" + role, Query = "" };
                index.Roles.Add(role, roleConfig.ToString());
            }
            return index;
        }

        // GET api/RoleApi/Maps
        public Role GetRoleModel(string id)
        {
            var r = db.RoleModels.Where(i => i.Role == id).Single();
            var role = new Role();
            role.RedirectBase = r.BaseUrl;
            return role;
        }

        // PUT api/RoleApi/5
        public async Task<IHttpActionResult> PutRoleModel(string id, RoleModel rolemodel)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            if (id != rolemodel.Role)
            {
                return BadRequest();
            }

            db.Entry(rolemodel).State = EntityState.Modified;

            try
            {
                await db.SaveChangesAsync();
            }
            catch (DbUpdateConcurrencyException)
            {
                if (!RoleModelExists(id))
                {
                    return NotFound();
                }
                else
                {
                    throw;
                }
            }

            return StatusCode(HttpStatusCode.NoContent);
        }

        // POST api/RoleApi
        [ResponseType(typeof(RoleModel))]
        public async Task<IHttpActionResult> PostRoleModel(RoleModel rolemodel)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            db.RoleModels.Add(rolemodel);

            try
            {
                await db.SaveChangesAsync();
            }
            catch (DbUpdateException)
            {
                if (RoleModelExists(rolemodel.Role))
                {
                    return Conflict();
                }
                else
                {
                    throw;
                }
            }

            return CreatedAtRoute("DefaultApi", new { id = rolemodel.Role }, rolemodel);
        }

        // DELETE api/RoleApi/5
        [ResponseType(typeof(RoleModel))]
        public async Task<IHttpActionResult> DeleteRoleModel(string id)
        {
            RoleModel rolemodel = await db.RoleModels.FindAsync(id);
            if (rolemodel == null)
            {
                return NotFound();
            }

            db.RoleModels.Remove(rolemodel);
            await db.SaveChangesAsync();

            return Ok(rolemodel);
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }

        private bool RoleModelExists(string id)
        {
            return db.RoleModels.Count(e => e.Role == id) > 0;
        }
    }
}