﻿//     Copyright (c) Microsoft Corporation.  All rights reserved.

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Threading.Tasks;
using System.Net;
using System.Web;
using System.Web.Mvc;
using Gateway.Console.Models;

namespace Gateway.Console.Controllers
{
    public class RoleController : Controller
    {
        private ConsoleContext db = new ConsoleContext();

        // GET: /Role/
        public async Task<ActionResult> Index()
        {
            return View(await db.RoleModels.ToListAsync());
        }

        // GET: /Role/Details/5
        public async Task<ActionResult> Details(string id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            RoleModel rolemodel = await db.RoleModels.FindAsync(id);
            if (rolemodel == null)
            {
                return HttpNotFound();
            }
            return View(rolemodel);
        }

        // GET: /Role/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: /Role/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public async Task<ActionResult> Create([Bind(Include="Role,BaseUrl")] RoleModel rolemodel)
        {
            if (ModelState.IsValid)
            {
                db.RoleModels.Add(rolemodel);
                await db.SaveChangesAsync();
                return RedirectToAction("Index");
            }

            return View(rolemodel);
        }

        // GET: /Role/Edit/5
        public async Task<ActionResult> Edit(string id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            RoleModel rolemodel = await db.RoleModels.FindAsync(id);
            if (rolemodel == null)
            {
                return HttpNotFound();
            }
            return View(rolemodel);
        }

        // POST: /Role/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public async Task<ActionResult> Edit([Bind(Include="Role,BaseUrl")] RoleModel rolemodel)
        {
            if (ModelState.IsValid)
            {
                db.Entry(rolemodel).State = EntityState.Modified;
                await db.SaveChangesAsync();
                return RedirectToAction("Index");
            }
            return View(rolemodel);
        }

        // GET: /Role/Delete/5
        public async Task<ActionResult> Delete(string id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            RoleModel rolemodel = await db.RoleModels.FindAsync(id);
            if (rolemodel == null)
            {
                return HttpNotFound();
            }
            return View(rolemodel);
        }

        // POST: /Role/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public async Task<ActionResult> DeleteConfirmed(string id)
        {
            RoleModel rolemodel = await db.RoleModels.FindAsync(id);
            db.RoleModels.Remove(rolemodel);
            await db.SaveChangesAsync();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
