﻿//     Copyright (c) Microsoft Corporation.  All rights reserved.

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Threading.Tasks;
using System.Net;
using System.Web;
using System.Web.Mvc;
using Gateway.Console.Models;

namespace Gateway.Console.Controllers
{
    public class SecurityController : Controller
    {
        private ConsoleContext db = new ConsoleContext();

        // GET: /Security/
        public async Task<ActionResult> Index()
        {
            return View(await db.SecurityModels.ToListAsync());
        }

        // GET: /Security/Details/5
        public async Task<ActionResult> Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            SecurityModel securitymodel = await db.SecurityModels.FindAsync(id);
            if (securitymodel == null)
            {
                return HttpNotFound();
            }
            return View(securitymodel);
        }

        // GET: /Security/Create
        public ActionResult Create()
        {
            return View();
        }

        // POST: /Security/Create
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public async Task<ActionResult> Create([Bind(Include="Id,Directory,ApplicationName")] SecurityModel securitymodel)
        {
            if (ModelState.IsValid)
            {
                db.SecurityModels.Add(securitymodel);
                await db.SaveChangesAsync();
                return RedirectToAction("Index");
            }

            return View(securitymodel);
        }

        // GET: /Security/Edit/5
        public async Task<ActionResult> Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            SecurityModel securitymodel = await db.SecurityModels.FindAsync(id);
            if (securitymodel == null)
            {
                return HttpNotFound();
            }
            return View(securitymodel);
        }

        // POST: /Security/Edit/5
        // To protect from overposting attacks, please enable the specific properties you want to bind to, for 
        // more details see http://go.microsoft.com/fwlink/?LinkId=317598.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public async Task<ActionResult> Edit([Bind(Include="Id,Directory,ApplicationName")] SecurityModel securitymodel)
        {
            if (ModelState.IsValid)
            {
                db.Entry(securitymodel).State = EntityState.Modified;
                await db.SaveChangesAsync();
                return RedirectToAction("Index");
            }
            return View(securitymodel);
        }

        // GET: /Security/Delete/5
        public async Task<ActionResult> Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            SecurityModel securitymodel = await db.SecurityModels.FindAsync(id);
            if (securitymodel == null)
            {
                return HttpNotFound();
            }
            return View(securitymodel);
        }

        // POST: /Security/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public async Task<ActionResult> DeleteConfirmed(int id)
        {
            SecurityModel securitymodel = await db.SecurityModels.FindAsync(id);
            db.SecurityModels.Remove(securitymodel);
            await db.SaveChangesAsync();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
