# Service Gateway #

## Overview ##

The service gateway makes it incredibly easy to enable service composition of web assets. Through a simple json.config you can control the configuration of

- Roles
- AuthN/AuthZ
- A/B Testing
- Tracing

## Getting Started ##

The following diagram depicts how to compose all contoso, fabrikam and litware inc web assets under well defined routes on the adatum domain.

 ![](https://resources.blob.core.windows.net/codeplex/architecture.PNG)

## Role Configuration ##

Roles allow routing to be configured based on:

- Url Segment
- Source IP
- User
- Tenant
- A/B/* testing i.e Load balanced using a Round Robin algorithm with custom weights.

The following is a simple example of how to configure routing based on url segment for the diagram depicted above.


1. Modify the contents of the Role Index file to add new roles for the Gateway. The Role Index file is a JSON document that lists all of the roles supported by the Gateway URIs pointing to the location of the configuration file for each role. Separating the configuration for each role permits different role administrators to manage their roles individually.  Note that each key, e.g "contoso", becomes the segment used for the corresponding roles json config
	
	roleindex.json:
	
	    {
	     Roles : {
	      "contoso" : "https://somestorageaccount.blob.core.windows.net/gatewayconfig/contosoconfig.json",
	      "fabrikam" : "https://somestorageaccount.blob.core.windows.net/gatewayconfig/fabrikamconfig.json",
	      "litwareinc" : "https://somestorageaccount.blob.core.windows.net/gatewayconfig/litwareincconfig.json",
	      "_Default" : "https://somestorageaccount.blob.core.windows.net/defaultconfig/default.json"
	     }
	    }
	    
	Note: the _Default role defines the fall through web asset that should be used if none of the other role segments are requested.



1. Define a Role Configuration file for each role listed in the Role Index file. The Role Configuration file defines the URL segment that identifies the role to the Gateway, the destination host plus any flighting configuration. Examples of the Role Configuration file follows:

	contosoconfig.json:
	
		{
		"RedirectBase" : "www.contoso.com"
		}
		
	fabrikamconfig.json:
	
		{
		"RedirectBase" : "www.fabrikam.com"
		}
		
	litwareincconfig.json:
	
		{
		"RedirectBase" : "www.adatum.com"
		}

	
	default.json:

	
		 {
		"RedirectBase" : "www.adatum.com"
		}

Now that routing is configured. Deployment can be achieved as follows.

## Deployment ##



1. Upload your roleindex  and role config files to your storage account.  In this case they would be uploaded to somestorageaccount.blob.core.windows.net/gatewayconfig
2. Update your ServiceConfiguration.Publish.cscfg to set the ConfigLocation value to point to a different RoleIndex file in this example it would be https://somestorageaccount.blob.core.windows.net/gatewayconfig/roleindex.json. 
Right click on the cloud project and select publish and ensure you use the ServiceConfiguration.Publish.cscfg config
1. Once deployed test your routing by navigating to the appropriate segments