﻿//     Copyright (c) Microsoft Corporation.  All rights reserved.

using Newtonsoft.Json;
using System;

namespace Microsoft.Gateway.Configuration
{
    public enum FlightPivots
    {
        Default = 0, 
        User    = 1,  
        Tenant  = 2, 
        SourceIP= 3
    }

    public class Flight : IEquatable<Flight>
    {
        public int Order { get; set; }       
        public FlightPivots Pivot { get; set; }
        public string Value { get; set; }
        public string RedirectBase { get; set; }

        public string GetEffectiveRedirectBase(Role containingRole)
        {
            if (String.IsNullOrWhiteSpace(this.RedirectBase))
            {
                return containingRole.RedirectBase;
            }
            return this.RedirectBase;
        }

        public bool Equals(Flight other)
        {
            if (other == null)
            {
                return false;
            }
            return this.Order == other.Order &&
                this.Pivot == other.Pivot &&
                String.Equals(this.Value, other.Value, StringComparison.OrdinalIgnoreCase) &&
                String.Equals(this.RedirectBase, other.RedirectBase, StringComparison.OrdinalIgnoreCase);
        }

        [JsonIgnore]
        public bool IsDefaultFlight
        {
            get { return this.Pivot == FlightPivots.Default; }
        }
    }
}
