﻿//     Copyright (c) Microsoft Corporation.  All rights reserved.

using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using Newtonsoft.Json;

namespace Microsoft.Gateway.Configuration
{
    public class Role : IEquatable<Role>
    {
        // Special Roles
        const string ROLE_NAME_DEFAULT = "_default";

        public Role()
        {
            this.Flights = new Dictionary<string, Flight>(StringComparer.OrdinalIgnoreCase);
        }

        public string Segment { get; set; }
        public string RedirectBase { get; set; }
        public IDictionary<string, Flight> Flights { get; private set; }
        [JsonIgnore]
        public IEnumerable<Tuple<string, Flight>> OrderedFlights
        {
            get
            {
                return this.Flights
                    .OrderBy(flight => flight.Value.Order)
                    .ThenBy(flight => flight.Key, StringComparer.OrdinalIgnoreCase)
                    .Select(flight => Tuple.Create(flight.Key, flight.Value));
            }
        }
        [JsonIgnore]
        public bool IsDefaultRole 
        {
            get { return String.Equals(this.Segment, ROLE_NAME_DEFAULT, StringComparison.OrdinalIgnoreCase); }
        }

        public bool Equals(Role other)
        {
            if (other == null)
            {
                return false;
            }
            return String.Equals(this.Segment, other.Segment, StringComparison.OrdinalIgnoreCase) &&
                String.Equals(this.RedirectBase, other.RedirectBase, StringComparison.OrdinalIgnoreCase) &&
                this.OrderedFlights
                    .SequenceEqual(other.OrderedFlights, new FlightTupleComparer());
        }

        class FlightTupleComparer : IEqualityComparer<Tuple<string, Flight>>
        {
            public bool Equals(Tuple<string, Flight> lhs, Tuple<string, Flight> rhs)
            {
                if (lhs == null && rhs == null)
                {
                    return true;
                }
                else if (lhs == null || rhs == null)
                {
                    return false;
                }
                return String.Equals(lhs.Item1, rhs.Item1, StringComparison.OrdinalIgnoreCase) && 
                    lhs.Item2.SafeEquals(rhs.Item2);
            }

            public int GetHashCode(Tuple<string, Flight> obj)
            {
                if (obj == null)
                {
                    return 0;
                }
                return obj.GetType().Name.GetHashCode();
            }
        }
    }
}
