﻿//     Copyright (c) Microsoft Corporation.  All rights reserved.

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using Newtonsoft.Json;

namespace Microsoft.Gateway.Configuration
{
    public class RulesConfiguration : IEquatable<RulesConfiguration>
    {
        public RulesConfiguration()
        {
            this.Roles = new Dictionary<string, Role>(StringComparer.OrdinalIgnoreCase);
        }

        public IDictionary<string, Role> Roles { get; private set; }
        public string Directory { get; set; }
        public string ApplicationName { get; set; }
        [JsonIgnore]
        public IEnumerable<Tuple<string, Role>> OrderedRoles
        {
            get
            {
                return this.Roles
                    .OrderBy(role => role.Value.IsDefaultRole ? 1 : 0)
                    .ThenBy(role => role.Key, StringComparer.OrdinalIgnoreCase)
                    .Select(role => Tuple.Create(role.Key, role.Value));
            }
        }

        public bool Equals(RulesConfiguration other)
        {
            if (other == null || 
                !String.Equals(this.Directory, other.Directory, StringComparison.OrdinalIgnoreCase) ||
                !String.Equals(this.ApplicationName, other.ApplicationName, StringComparison.OrdinalIgnoreCase))
            {
                return false;
            }
            if (this.Roles.Count != other.Roles.Count)
            {
                return false;
            }
            return this.Roles.Keys
                    .OrderBy(key => key, StringComparer.OrdinalIgnoreCase)
                    .SequenceEqual(other.Roles.Keys.OrderBy(key => key, StringComparer.OrdinalIgnoreCase)) &&
                this.Roles
                    .OrderBy(role => role.Key, StringComparer.OrdinalIgnoreCase)
                    .Select(role => role.Value)
                    .SequenceEqual(other.Roles
                        .OrderBy(role => role.Key, StringComparer.OrdinalIgnoreCase)
                        .Select(role => role.Value));
        }
    }
}
