﻿//     Copyright (c) Microsoft Corporation.  All rights reserved.

using System;
using System.Linq;
using System.Web;

namespace GatewayTracingModule
{
    public class AuthHook : IGatewayModuleInit
    {
        private const string GatewayRemoteUser = "GW-REMOTE-USER";

        public void Init(System.Web.HttpApplication context)
        {
            context.AuthenticateRequest += OnAuthenticateRequest;
            context.EndRequest += OnEndRequest;
        }

        void OnEndRequest(object sender, EventArgs e)
        {
            var app = sender as HttpApplication;
                        
            if (app != null && app.Response.Cookies.AllKeys.Contains("FedAuth") && app.User != null)
            {
                app.Response.AppendCookie(new HttpCookie("UPN", app.User.Identity.Name));
            }
        }

        void OnAuthenticateRequest(object sender, EventArgs e)
        {
             var context = ((HttpApplication)sender).Context;
            var value = context.Request.ServerVariables["REMOTE_USER"];
            context.Response.Headers.Set(GatewayRemoteUser, string.IsNullOrEmpty(value) ? "" : value);
        }
    }
}
